TracingConfig

Struct TracingConfig 

pub struct TracingConfig { /* private fields */ }
Represents the application-level configuration section that covers everything related to pre-configuring the formatted layer provided by the tracing crate. In essence, this is the application logging configuration.

Implementations

Source

impl TracingConfig

pub fn with_target( self, target: impl Into<String>, verbosity: impl Into<Verbosity>, ) -> Self

Merges an extra per-target Verbosity level into this config.

pub fn with_targets<T, L>( self, targets: impl IntoIterator<Item = (T, L)>, ) -> Self
where T: Into<String>, L: Into<Verbosity>,

Merges extra per-target Verbosity levels into this config.

Source

impl TracingConfig

pub fn verbosity(&self) -> Verbosity

Reports the root verbosity level for this logging configuration.

pub fn flavor(&self) -> FormatFlavor

Reports the formatting flavor for this logging configuration.

pub fn color(&self) -> bool

Reports whether this logging configuration enables colored output.

pub fn show_timestamp(&self) -> bool

Reports whether this logging configuration includes the timestamp in the output.

pub fn show_target(&self) -> bool

Reports whether this logging configuration includes the target in the output.

pub fn show_file(&self) -> bool

Reports whether this logging configuration includes the file in the output.

pub fn show_line_number(&self) -> bool

Reports whether this logging configuration includes the line number in the output.

pub fn show_level(&self) -> bool

Reports whether this logging configuration includes the level in the output.

pub fn show_thread_id(&self) -> bool

Reports whether this logging configuration includes the thread ID in the output.

pub fn show_thread_name(&self) -> bool

Reports whether this logging configuration includes the thread name in the output.

pub fn targets(&self) -> &BTreeMap<String, Verbosity>

Reports the customized per-target verbosity for this logging configuration.